@@ -2,22 +2,22 @@ use 5.014002;
 package Aniki {
     use namespace::sweep;
     use Mouse;
+    use Module::Load ();
     use Aniki::Row;
     use Aniki::Collection;
     use Aniki::Schema;
     use Aniki::QueryBuilder;
 
-    our $VERSION = '0.01_03';
+    our $VERSION = '0.02_01';
 
-    use Module::Load ();
     use SQL::Maker::SQLType qw/sql_type/;
     use DBIx::Sunny;
     use DBIx::Handler;
     use Carp qw/croak/;
     use Try::Tiny;
-    use Module::Load ();
     use Scalar::Util qw/blessed/;
     use String::CamelCase qw/camelize/;
+    use SQL::NamedPlaceholder qw/bind_named/;
 
     has connect_info => (
         is       => 'ro',
@@ -74,15 +74,18 @@ package Aniki {
     sub row_class     { croak 'This is abstract method.' }
     sub result_class  { croak 'This is abstract method.' }
 
+    # You can override this method on your application.
+    sub use_strict_query_builder { 1 }
+
     sub setup {
         my ($class, %args) = @_;
 
         if (my $schema_class = $args{schema}) {
             Module::Load::load($schema_class);
 
-            my $schema        = Aniki::Schema->new(context => $schema_class->context);
+            my $schema        = Aniki::Schema->new(schema_class => $schema_class);
             my $driver        = $class->_database2driver($schema->database);
-            my $query_builder = Aniki::QueryBuilder->new(driver => $driver);
+            my $query_builder = Aniki::QueryBuilder->new(driver => $driver, strict => $class->use_strict_query_builder);
 
             $class->meta->add_method(schema        => sub { $schema        });
             $class->meta->add_method(query_builder => sub { $query_builder });
@@ -134,20 +137,47 @@ package Aniki {
     }
 
     sub update {
-        my ($self, $table_name, $row, $where, $opt) = @_;
-        $row = $self->filter_on_update($table_name, $row);
-
-        my $table = $self->schema->get_table($table_name);
-        if ($table) {
-            $row   = $self->_bind_sql_type_to_args($table, $row);
-            $where = $self->_bind_sql_type_to_args($table, $where);
+        my $self = shift;
+        if (blessed $_[0] && $_[0]->isa('Aniki::Row')) {
+            return $self->update($_[0]->table_name, $_[1], $self->_where_row_cond($_[0]->table, $_[0]->row_data), @_);
         }
+        else {
+            my ($table_name, $row, $where, $opt) = @_;
+            $row = $self->filter_on_update($table_name, $row);
 
-        my ($sql, @bind) = $self->query_builder->update($table_name, $row, $where, $opt);
-        my $sth  = $self->execute($sql, @bind);
-        my $rows = $sth->rows;
-        $sth->finish;
-        return $rows;
+            my $table = $self->schema->get_table($table_name);
+            if ($table) {
+                $row   = $self->_bind_sql_type_to_args($table, $row);
+                $where = $self->_bind_sql_type_to_args($table, $where);
+            }
+
+            my ($sql, @bind) = $self->query_builder->update($table_name, $row, $where, $opt);
+            my $sth  = $self->execute($sql, @bind);
+            my $rows = $sth->rows;
+            $sth->finish;
+            return $rows;
+        }
+    }
+
+    sub delete :method {
+        my $self = shift;
+        if (blessed $_[0] && $_[0]->isa('Aniki::Row')) {
+            return $self->delete($_[0]->table_name, $self->_where_row_cond($_[0]->table, $_[0]->row_data), @_);
+        }
+        else {
+            my ($table_name, $where, $opt) = @_;
+
+            my $table = $self->schema->get_table($table_name);
+            if ($table) {
+                $where = $self->_bind_sql_type_to_args($table, $where);
+            }
+
+            my ($sql, @bind) = $self->query_builder->delete($table_name, $where, $opt);
+            my $sth  = $self->execute($sql, @bind);
+            my $rows = $sth->rows;
+            $sth->finish;
+            return $rows;
+        }
     }
 
     sub filter_on_update {
@@ -174,7 +204,10 @@ package Aniki {
         my $table = $self->schema->get_table($table_name) or croak "$table_name is not defined in schema.";
         $self->insert($table_name, $row_data, @_);
         return unless defined wantarray;
-        return $self->select($table_name, $self->_where_row_cond($table, $row_data), { limit => 1 })->first;
+
+        my $row = $self->select($table_name, $self->_where_row_cond($table, $row_data), { limit => 1 })->first;
+        $row->is_new(1);
+        return $row;
     }
 
     sub insert_on_duplicate {
@@ -271,6 +304,11 @@ package Aniki {
         }
     }
 
+    sub select_named {
+        my ($self, $sql, $bind, $opt) = @_;
+        return $self->select_by_sql(bind_named($sql, $bind), $opt);
+    }
+
     sub select_by_sql {
         my ($self, $sql, $bind, $opt) = @_;
         $opt //= {};
@@ -365,6 +403,7 @@ package Aniki {
 
     # --------------------------------------------------
     # for transaction
+    sub txn_manager  { shift->handler->txn_manager }
     sub txn          { shift->handler->txn(@_)          }
     sub in_txn       { shift->handler->in_txn(@_)       }
     sub txn_scope    { shift->handler->txn_scope(@_)    }
@@ -471,7 +510,9 @@ Aniki - The ORM as our great brother.
     };
 
     package main {
-        my $db = MyProj::DB->new(connect_info => [...]);
+        my $db = MyProj::DB->new(connect_info => ["dbi:SQLite:dbname=:memory:", "", ""]);
+        $db->execute($_) for split /;/, MyProj::DB::Schema->output;
+
         my $author_id = $db->insert_and_fetch_id(author => { name => 'songmu' });
 
         $db->insert(module => {
@@ -488,17 +529,18 @@ Aniki - The ORM as our great brother.
         }, {
             limit => 1,
         })->first;
-        $module->name;         ## Riji
-        $module->author->name; ## SONGMU
+        say '$module->name:         ', $module->name;         ## Riji
+        say '$module->author->name: ', $module->author->name; ## SONGMU
 
         my $author = $db->select(author => {
             name => 'songmu',
         }, {
             limit => 1,
-            relay => [qw/module/],
+            relay => [qw/modules/],
         })->first;
-        $author->name;                 ## SONGMU
-        $_->name for $author->modules; ## DBIx::Schema::DSL, Riji
+
+        say '$author->name:   ', $author->name;                 ## SONGMU
+        say 'modules[]->name: ', $_->name for $author->modules; ## DBIx::Schema::DSL, Riji
     };
 
     1;
